@@ -1,9 +1,10 @@
 import json
-import tensorflow as tf
-tf.get_logger().setLevel('INFO')
-
-from PIL import Image, ImageDraw
 import os
+os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2' 
+import tensorflow as tf
+tf.get_logger().setLevel('ERROR')
+tf.compat.v1.logging.set_verbosity(tf.compat.v1.logging.ERROR) 
+from PIL import Image, ImageDraw
 import numpy as np 
 import cv2
 import functools
@@ -17,7 +18,7 @@ from object_detection.utils import config_util
 from object_detection.utils import label_map_util
 from tensorboard.backend.event_processing.event_accumulator import EventAccumulator
 from object_detection.builders import dataset_builder
-from object_detection.builders import graph_rewriter_builder
+from object_detection.builders import graph_rewriter_builder    
 from object_detection.builders import model_builder
 from object_detection.legacy import trainer
 from object_detection.legacy import evaluator
@@ -398,7 +399,7 @@ def edit_config(model_selected, input_config_dir, output_config_dir, num_steps,
 
     configs = config_util.get_configs_from_pipeline_file(os.path.join(input_config_dir,'pipeline.config'))
     label_map = label_map_util.load_labelmap(label_map_path)
-
+    num_steps += configs["train_config"].num_steps
     config_util._update_train_steps(configs, num_steps)
     update_different_paths(configs, ckpt_path=ckpt_path, 
                             label_map_path=label_map_path, 
@@ -429,7 +430,7 @@ def edit_config(model_selected, input_config_dir, output_config_dir, num_steps,
 
 
 def train(ckpt_dir='', config_dir='', train_steps=None, use_tpu=False, checkpoint_every_n=100,
-          record_summaries=True):
+          record_summaries=True, log_real_time=None):
 
     if config_dir.endswith('.config'):
         if not os.path.isfile(config_dir):
@@ -458,7 +459,8 @@ def train(ckpt_dir='', config_dir='', train_steps=None, use_tpu=False, checkpoin
           train_steps=train_steps,
           use_tpu=use_tpu,
           checkpoint_every_n=checkpoint_every_n,
-          record_summaries=record_summaries)
+          record_summaries=record_summaries,
+          log_real_time=log_real_time)
 
 
 def evaluate(metrics_dir='', config='', ckpt_dir=''):
